The Topology (xentica\.core\.topology)
======================================

.. automodule:: xentica.core.topology

Lattice (xentica\.core\.topology\.lattice)
------------------------------------------

.. automodule:: xentica.core.topology.lattice
    :members:
    :undoc-members:
    :show-inheritance:

Neighborhood (xentica\.core\.topology\.neighborhood)
----------------------------------------------------

.. automodule:: xentica.core.topology.neighborhood
    :members:
    :undoc-members:
    :show-inheritance:

Border (xentica\.core\.topology\.border)
----------------------------------------

.. automodule:: xentica.core.topology.border
    :members:
    :undoc-members:
    :show-inheritance:

Mixins (xentica\.core\.topology\.mixins)
----------------------------------------

.. automodule:: xentica.core.topology.mixins
    :members:
    :undoc-members:
    :show-inheritance:

